==============
 Introduction
==============

These pages describe a git_ and github_ workflow for the nipype_
project.

There are several different workflows here, for different ways of
working with *nipype*.

This is not a comprehensive git_ reference, it's just a workflow for our
own project.  It's tailored to the github_ hosting service. You may well
find better or quicker ways of getting stuff done with git_, but these
should get you started.

For general resources for learning git_ see :ref:`git-resources`.

.. include:: links.inc
